==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridSummaryDescriptionsChangedEventArgsDescription } from "./GridSummaryDescriptionsChangedEventArgsDescription";
/**
 * @hidden
 */
export let GridSummaryDescriptionsChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridSummaryDescriptionsChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a == null) {
                GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.c(GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a);
            }
            if (a.j(GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("SummaryDescriptions", "Collection:ColumnSummaryDescription:ColumnSummaryDescriptionCollection:ColumnSummaryDescription");
        }
        static d(a) {
            GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.b(a);
            a.aa("GridSummaryDescriptionsChangedEventArgs", () => new GridSummaryDescriptionsChangedEventArgsDescription());
            a.z("GridSummaryDescriptionsChangedEventArgs", GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a);
        }
    }
    GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridSummaryDescriptionsChangedEventArgsDescriptionMetadata, 'GridSummaryDescriptionsChangedEventArgsDescriptionMetadata');
    GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a = null;
    return GridSummaryDescriptionsChangedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridSummaryDescriptionsChangedEventArgsDescription } from "./GridSummaryDescriptionsChangedEventArgsDescription";
/**
 * @hidden
 */
export let GridSummaryDescriptionsChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridSummaryDescriptionsChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a == null) {
                GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.c(GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("SummaryDescriptions", "Collection:ColumnSummaryDescription:ColumnSummaryDescriptionCollection:ColumnSummaryDescription");
        }
        static d(a) {
            GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.b(a);
            a.ac("GridSummaryDescriptionsChangedEventArgs", () => new GridSummaryDescriptionsChangedEventArgsDescription());
            a.ab("GridSummaryDescriptionsChangedEventArgs", GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a);
        }
    }
    GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridSummaryDescriptionsChangedEventArgsDescriptionMetadata, 'GridSummaryDescriptionsChangedEventArgsDescriptionMetadata');
    GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a = null;
    return GridSummaryDescriptionsChangedEventArgsDescriptionMetadata;
})();
